// SPDX-License-Identifier: GPL-2.0-or-later
// Copyright The Music Player Daemon Project

#ifndef MPD_EMBCUE_PLAYLIST_PLUGIN_HXX
#define MPD_EMBCUE_PLAYLIST_PLUGIN_HXX

extern const struct PlaylistPlugin embcue_playlist_plugin;

#endif
